User: aidan
Date: 06/07/16 14:29:53
Modified: packages/xemacs-packages/mail-lib ChangeLog sendmail.el
Log:
Fix some sendmail.el problems introduced by a GNU sync.
Revision Changes Path
1.168 +13 -0 XEmacs/packages/xemacs-packages/mail-lib/ChangeLog
Index: ChangeLog
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/mail-lib/ChangeLog,v
retrieving revision 1.167
retrieving revision 1.168
diff -u -p -r1.167 -r1.168
--- ChangeLog 2006/03/08 12:51:16 1.167
+++ ChangeLog 2006/07/16 12:29:52 1.168
@@ -1,3 +1,16 @@
+2006-07-16 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * sendmail.el (sendmail-send-it):
+ Use no-conversion-unix for writing to sendmail, rather than the
+ buffer default, which breaks any externally-implemented MIME
+ handling.
+ * sendmail.el (mail-do-fcc):
+ * sendmail.el (mail-recover-1):
+ * sendmail.el (mail-recover):
+ emacs-mule -> escape-quoted. XEmacs doesn't have the emacs-mule
+ coding system available, and rightly so, since escape-quoted fills
+ the same role and exposes the internal text representation less.
+
2006-03-08 Norbert Koch <viteno(a)xemacs.org>
* Makefile (VERSION): XEmacs package 1.76 released.
1.20 +25 -14 XEmacs/packages/xemacs-packages/mail-lib/sendmail.el
Index: sendmail.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/packages/xemacs-packages/mail-lib/sendmail.el,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -p -r1.19 -r1.20
--- sendmail.el 2005/04/01 22:28:07 1.19
+++ sendmail.el 2006/07/16 12:29:52 1.20
@@ -1039,8 +1039,8 @@ external program defined by `sendmail-pr
\\|^resent-cc:\\|^resent-bcc:"
delimline t))
(let* ((default-directory "/")
- ;; XEmacs: commented out #### why?
-; (coding-system-for-write selected-coding)
+ ;; XEmacs: changed to no-conversion-unix
+ (coding-system-for-write 'no-conversion-unix)
(args
(append (list (point-min) (point-max)
program
@@ -1214,7 +1214,12 @@ external program defined by `sendmail-pr
;; convert the message to Babyl format.
(let ((coding-system-for-write
(or rmail-file-coding-system
- 'emacs-mule)))
+ ;; XEmacs change; emacs-mule is not available,
+ ;; escape-quoted serves much the same
+ ;; purpose. #### This means an incompatibility
+ ;; with Babyl files created with GNU Emacs, but
+ ;; that's probably okay, since no-one uses them.
+ 'escape-quoted)))
(save-excursion
(set-buffer (get-buffer-create " mail-temp"))
(setq buffer-read-only nil)
@@ -1747,7 +1752,9 @@ The seventh argument ACTIONS is a list o
(define-key (current-local-map) "v"
(lambda ()
(interactive)
- (let ((coding-system-for-read 'emacs-mule-unix))
+ ;; XEmacs change; emacs-mule is not available, escape-quoted
+ ;; serves the same purpose.
+ (let ((coding-system-for-read 'escape-quoted))
(dired-view-file))))
(define-key (current-local-map) "\C-c\C-c"
(lambda ()
@@ -1755,19 +1762,21 @@ The seventh argument ACTIONS is a list o
(let ((fname (dired-get-filename))
;; Auto-saved files are written in the internal
;; representation, so they should be read accordingly.
- (coding-system-for-read 'emacs-mule-unix))
+ ;; XEmacs change; emacs-mule is not available, escape-quoted
+ ;; serves the same purpose.
+ (coding-system-for-read 'escape-quoted))
(switch-to-buffer-other-window "*mail*")
(let ((buffer-read-only nil))
(erase-buffer)
(insert-file-contents fname nil)
;; insert-file-contents will set buffer-file-coding-system
;; to emacs-mule, which is probably not what they want to
;; use for sending the message. But we don't know what
;; was its value before the buffer was killed or Emacs
;; crashed. We therefore reset buffer-file-coding-system
;; to the default value, so that either the default does
;; TRT, or the user will get prompted for the right
;; encoding when they send the message.
(setq buffer-file-coding-system
default-buffer-file-coding-system))))))))
@@ -1812,7 +1821,9 @@ you can move to one of them and type C-c
(buffer-coding buffer-file-coding-system)
;; Auto-save files are written in internal
;; representation of non-ASCII characters.
- (coding-system-for-read 'emacs-mule-unix))
+ ;; XEmacs change; emacs-mule is not available,
+ ;; escape-quoted serves the same purpose.
+ (coding-system-for-read 'escape-quoted))
(erase-buffer)
(insert-file-contents file-name nil)
(setq buffer-file-coding-system buffer-coding)))))
@@ -1755,19 +1762,21 @@ The seventh argument ACTIONS is a list o
(erase-buffer)
(insert-file-contents fname nil)
- ;; insert-file-contents will set buffer-file-coding-system
- ;; to emacs-mule, which is probably not what they want to
- ;; use for sending the message. But we don't know what
- ;; was its value before the buffer was killed or Emacs
- ;; crashed. We therefore reset buffer-file-coding-system
- ;; to the default value, so that either the default does
- ;; TRT, or the user will get prompted for the right
- ;; encoding when they send the message.
+ ;; insert-file-contents will set buffer-file-coding-system to
+ ;; escape-quoted on XEmacs, which is not what they want to use
+ ;; for sending the message. But we don't know what was its
+ ;; value before the buffer was killed or Emacs crashed. We
+ ;; therefore reset buffer-file-coding-system to the default
+ ;; value, so that either the default does TRT, or the user
+ ;; will get prompted for the right encoding when they send the
+ ;; message.
(setq buffer-file-coding-system
default-buffer-file-coding-system))))))))
Show replies by date